@@ -1,7 +1,7 @@
 
 from seti_python.class_read import ResponseReadCash, ResponseReadCashOut, ResponseReadPayment, ResponseReadTransactions, ResponseReadWallet, ResponseReadWalletsTransactions
 from seti_python.wallet_class import ResponseCreateWallet
-from seti_python.class_tools import BasicResponse, CompleteBasicaResponse, ResponseCreateTransaction
+from seti_python.class_tools import BasicResponse, CompleteBasicaResponse, ResponseCreateDispersions, ResponseCreateTransaction
 from seti_python.payment_class import ResponseCreatePayment
 from typing import List
 import execjs
@@ -212,7 +212,7 @@ class Seti():
         }
         CREATE_DISPERSION_URL = "dispersion-money"
         encode_data = self.sign_data(data_create_dispersion)
-        return ResponseCreateTransaction(self.send_request(data_create_dispersion,encode_data,CREATE_DISPERSION_URL))
+        return ResponseCreateDispersions(self.send_request(data_create_dispersion,encode_data,CREATE_DISPERSION_URL))
     
     def create_dispersion_associated(self,value:int,to_secret:str):
         self.is_error =False
