@@ -39,16 +39,16 @@ class ResponseReadPaymentData:
     def __init__(self,data:dict):
         try:
             self.commission =data['commission']
-            self.currency= data["currency"],
-            self.description= data["description"],
-            self.payer_email=data["payerEmail"],
-            self.payer_name= data["payerName"],
-            self.payment_id= data["paymentId"],
-            self.payment_method_type= data["paymentMethodType"],
-            self.payment_status= data["paymentStatus"],
-            self.redirect_url=data["redirectUrl"],
-            self.reference= data["reference"],
-            self.timestamp= data["timestamp"],
+            self.currency= data["currency"]
+            self.description= data["description"]
+            self.payer_email=data["payerEmail"]
+            self.payer_name= data["payerName"]
+            self.payment_id= data["paymentId"]
+            self.payment_method_type= data["paymentMethodType"]
+            self.payment_status= data["paymentStatus"]
+            self.redirect_url=data["redirectUrl"]
+            self.reference= data["reference"]
+            self.timestamp= data["timestamp"]
             self.url = data["url"]
             self.value = data["value"]
             self.taxes = Taxes(data['taxes'])
